@@ -537,50 +537,23 @@ extern "C" void _rxode2random_assignSolveOnly2(rx_solve rx,
   fun(rx, op);
 }
 
-extern "C" void _rxode2parseAssignPtrsInRxode2(rx_solve rx,
-                                               rx_solving_options op,
-                                               t_F f,
-                                               t_LAG lag,
-                                               t_RATE rate,
-                                               t_DUR dur, 
-                                               t_calc_mtime mtime,
-                                               t_ME me,
-                                               t_IndF indf,
-                                               t_getTime gettime,
-                                               t_locateTimeIndex timeindex,
-                                               t_handle_evidL handleEvid,
-                                               t_getDur getdur) {
-  static void (*fun)(rx_solve,
-                     rx_solving_options,
-                     t_F,
-                     t_LAG,
-                     t_RATE,
-                     t_DUR,
-                     t_calc_mtime,
-                     t_ME,
-                     t_IndF,
-                     t_getTime,
-                     t_locateTimeIndex,
-                     t_handle_evidL,
-                     t_getDur) = NULL;
-  if (fun == NULL) {
-    fun = (void (*)(rx_solve,
-                    rx_solving_options,
-                    t_F,
-                    t_LAG,
-                    t_RATE,
-                    t_DUR,
-                    t_calc_mtime,
-                    t_ME,
-                    t_IndF,
-                    t_getTime,
-                    t_locateTimeIndex,
-                    t_handle_evidL,
-                    t_getDur)) R_GetCCallable("rxode2parse","_rxode2parseAssignPtrs");
-  }
-  fun(rx, op, f, lag, rate, dur, mtime, me, indf, gettime, timeindex, handleEvid, getdur);
+extern "C" {
+  typedef void (*_rxode__assignFuns2_t)(rx_solve rx,
+                                        rx_solving_options op,
+                                        t_F f,
+                                        t_LAG lag,
+                                        t_RATE rate,
+                                        t_DUR dur,
+                                        t_calc_mtime mtime,
+                                        t_ME me,
+                                        t_IndF indf,
+                                        t_getTime gettime,
+                                        t_locateTimeIndex timeindex,
+                                        t_handle_evidL handleEvid,
+                                        t_getDur getdur);
 }
 
+
 extern "C" int _locateTimeIndex(double obs_time,  rx_solving_options_ind *ind);
 
 void rxUpdateFuns(SEXP trans){
@@ -637,19 +610,22 @@ void rxUpdateFuns(SEXP trans){
   rx->subjects = inds_global;
   rx_solving_options *op = &op_global;
   rx->op = op;
-  _rxode2parseAssignPtrsInRxode2(rx_global,
-                                 op_global,
-                                 AMT,
-                                 LAG,
-                                 RATE,
-                                 DUR, 
-                                 calc_mtime,
-                                 ME,
-                                 IndF,
-                                 getTime,
-                                 _locateTimeIndex,
-                                 handle_evidL,
-                                 _getDur);
+  char s_assignFuns2[300];
+  snprintf(s_assignFuns2, 300, "%s2", s_assignFuns);
+  _rxode__assignFuns2_t f2 = (_rxode__assignFuns2_t) R_GetCCallable(lib, s_assignFuns2);
+  f2(rx_global,
+     op_global,
+     AMT,
+     LAG,
+     RATE,
+     DUR, 
+     calc_mtime,
+     ME,
+     IndF,
+     getTime,
+     _locateTimeIndex,
+     handle_evidL,
+     _getDur);
   _rxode2random_assignSolveOnly2(rx_global, op_global);
 }
 
